[prev in list] [next in list] [prev in thread] [next in thread] 

List:       gstreamer-cvs
Subject:    [gst-cvs] gst-plugins-bad: asfmux: Set video stream seekable
From:       thiagoss () kemper ! freedesktop ! org (Thiago Sousa Santos)
Date:       2009-07-31 3:24:14
Message-ID: 20090731032414.6B79410051 () kemper ! freedesktop ! org
[Download RAW message or body]

Module: gst-plugins-bad
Branch: master
Commit: 7583bf6813501a071700522c8bb227afdb4471af
URL:    http://cgit.freedesktop.org/gstreamer/gst-plugins-bad/commit/?id=7583bf6813501a071700522c8bb227afdb4471af


Author: Thiago Santos <thiagoss@embedded.ufcg.edu.br>
Date:   Thu Jul 30 00:19:18 2009 -0300

asfmux: Set video stream seekable property to true

Video stream always have indexes, so they are all seekable

---

 gst/asfmux/gstasfmux.c |    8 +++++++-
 1 files changed, 7 insertions(+), 1 deletions(-)

diff --git a/gst/asfmux/gstasfmux.c b/gst/asfmux/gstasfmux.c
index edc4bb7..83f5270 100644
--- a/gst/asfmux/gstasfmux.c
+++ b/gst/asfmux/gstasfmux.c
@@ -846,7 +846,13 @@ gst_asf_mux_write_extended_stream_properties (GstAsfMux * \
asfmux, guint8 ** buf,  GST_WRITE_UINT32_LE (*buf + 64, 0);   /* maximum object size \
*/  
   /* flags */
-  GST_WRITE_UINT32_LE (*buf + 68, 0x0); /* TODO check if seekable */
+  if (asfpad->is_audio) {
+    /* TODO check if audio is seekable */
+    GST_WRITE_UINT32_LE (*buf + 68, 0x0);
+  } else {
+    /* video has indexes, so it is seekable */
+    GST_WRITE_UINT32_LE (*buf + 68, 0x2);
+  }
 
   GST_WRITE_UINT16_LE (*buf + 72, asfpad->stream_number);
   GST_WRITE_UINT16_LE (*buf + 74, 0);   /* language index */


------------------------------------------------------------------------------
Let Crystal Reports handle the reporting - Free Crystal Reports 2008 30-Day 
trial. Simplify your report design, integration and deployment - and focus on 
what you do best, core application coding. Discover what's new with 
Crystal Reports now.  http://p.sf.net/sfu/bobj-july
_______________________________________________
gstreamer-cvs mailing list
gstreamer-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/gstreamer-cvs


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic